pub struct InstanceWrapper<M: RemoteMessage> { /* private fields */ }Expand description
Wrapper around an instance of an actor that provides utilities to implement a python actor. This helps by allowing users to specialize the actor to the message type they want to handle.
Implementations
Sourceimpl<M: RemoteMessage> InstanceWrapper<M>
impl<M: RemoteMessage> InstanceWrapper<M>
pub fn new(proc: &PyProc, actor_name: &str) -> Result<Self>
Sourcepub fn send(&self, actor_id: &PyActorId, message: &PySerialized) -> PyResult<()>
pub fn send(&self, actor_id: &PyActorId, message: &PySerialized) -> PyResult<()>
Send a message to any actor. It is the responsibility of the caller to ensure the right payload accepted by the target actor has been serialized and provided to this function.
Sourcepub async fn next_message(
&mut self,
timeout_msec: Option<u64>,
) -> Result<Option<M>>
pub async fn next_message( &mut self, timeout_msec: Option<u64>, ) -> Result<Option<M>>
Get the next message from the queue. It will wait until a message is received or the timeout is reached in which case it will return None.
Sourcepub fn drain_and_stop(&mut self) -> Result<Vec<M>>
pub fn drain_and_stop(&mut self) -> Result<Vec<M>>
Put the actor in stopped mode and return any messages that were received.
pub fn instance(&self) -> &Instance<()>
pub fn actor_id(&self) -> &ActorId